#ifndef NT2_INCLUDE_FUNCTIONS_RATFRACDER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RATFRACDER_HPP_INCLUDED

#include <nt2/polynom/include/functions/ratfracder.hpp>

#endif
